@@ -3,7 +3,7 @@ PrintPath<-function(trace,step,obs,moveto,movefrom,lambda,digits,stats){
     moveto<-rep(moveto,length=length(obs))
     movefrom<-rep(movefrom,length=length(obs))
   for(i in seq(along=obs)){
-    cat(step,":\tObs ",obs[i],"\t",movefrom[i],"->",moveto[i],"  lambda = ",format(lambda, digits=digits,nsmall=digits),"  Margin = ",format(round(stats$margin,2))," Elbow = ",stats$selbow," Error = ",stats$error,"\n",sep="")
+    cat(step,":\tObs ",obs[i],"\t",movefrom[i],"->",moveto[i],"  lambda = ",format(lambda, digits=digits,nsmall=digits),"  Sum Eps = ",format(round(stats$margin,2))," Elbow = ",stats$selbow," Error = ",stats$error,"\n",sep="")
   }
 }
   invisible()
